@@ -21,9 +21,10 @@
 #######################################################
 
 package ExcelxFormat;
+use strict;
+use warnings;
+use version; our $VERSION = qv('2.3.28');
 
-# use Spreadsheet::ParseXLSX;
-# use Spreadsheet::Read;
 use Spreadsheet::XLSX;
 # use Spreadsheet::ParseExcel;
 use Ftree::DataParsers::ExtendedSimonWardFormat
@@ -85,8 +86,8 @@ foreach my $sheet ( @{ $excel->{Worksheet} } ) {
     }
      
     if ( defined $config_->{photo_dir} ) {
-        ExtendedSimonWardFormat::setPictureDirectory( $config_->{photo_dir} );
-        ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
+        Ftree::ExtendedSimonWardFormat::setPictureDirectory( $config_->{photo_dir} );
+        Ftree::ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
     }
 
     return $family_tree_data;
