@@ -22,9 +22,12 @@
 
 
 package SerializerFormat;
-use DataParsers::FieldValidatorParser;
-use DataParsers::ExtendedSimonWardFormat; # for getting pictures. Temporal solution
-use FamilyTreeData;
+use strict;
+use warnings;
+use version; our $VERSION = qv('2.3.28');
+use Ftree::DataParsers::FieldValidatorParser;
+use Ftree::DataParsers::ExtendedSimonWardFormat; # for getting pictures. Temporal solution
+use Ftree::FamilyTreeData;
 use Storable;
 use CGI::Carp qw(fatalsToBrowser);
 
@@ -34,11 +37,11 @@ sub createFamilyTreeDataFromFile {
 
   my $family_tree_data = Storable::retrieve($file_name);
   if(defined $config_->{photo_dir}) {
-    ExtendedSimonWardFormat::setPictureDirectory($config_->{photo_dir});
-    ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
+    Ftree::ExtendedSimonWardFormat::setPictureDirectory($config_->{photo_dir});
+    Ftree::ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
   }
   
   return $family_tree_data;
 }
 
-1;
\ No newline at end of file
+1;
