@@ -1,5 +1,7 @@
 package Ftree::Date::Tiny;
-
+use strict;
+use warnings;
+use version; our $VERSION = qv('2.3.28');
 =pod
 
 =head1 NAME
