@@ -21,7 +21,9 @@
 #######################################################
 
 package Serializer;
-
+use strict;
+use warnings;
+use version; our $VERSION = qv('2.3.28');
 use Storable;
 use Params::Validate qw(:all);
 
@@ -30,4 +32,4 @@ sub export {
   Storable::nstore $family_tree_data, $filename;
 }
 
-1;
\ No newline at end of file
+1;
